[pitivi] replace GObject.SIGNAL_RUN_LAST with GObject.SignalFlags.RUN_LAST as warning using command line: fi



commit 2a3ec9919b8b59f80e46bc7e74971f363d56c64e
Author: sprhawk <465558+sprhawk users noreply github com>
Date:   Wed Feb 13 13:09:27 2019 +0800

    replace GObject.SIGNAL_RUN_LAST with GObject.SignalFlags.RUN_LAST as warning using command line:  find . 
-iname *.py -exec sed -i -e 's/GObject\.SIGNAL_RUN_LAST/GObject\.SignalFlags\.RUN_LAST/' \{} \;

 pitivi/application.py                 |  2 +-
 pitivi/dialogs/filelisterrordialog.py |  4 ++--
 pitivi/effects.py                     |  4 ++--
 pitivi/project.py                     | 20 ++++++++++----------
 pitivi/render.py                      |  4 ++--
 pitivi/settings.py                    |  2 +-
 pitivi/shortcuts.py                   |  2 +-
 pitivi/timeline/elements.py           |  8 ++++----
 pitivi/timeline/previewers.py         |  4 ++--
 pitivi/undo/undo.py                   | 12 ++++++------
 pitivi/utils/proxy.py                 |  8 ++++----
 pitivi/utils/threads.py               |  2 +-
 pitivi/utils/timeline.py              |  4 ++--
 tests/test_plugin_manager.py          |  2 +-
 14 files changed, 39 insertions(+), 39 deletions(-)
---
diff --git a/pitivi/application.py b/pitivi/application.py
index f7b2a85d..05ec092c 100644
--- a/pitivi/application.py
+++ b/pitivi/application.py
@@ -65,7 +65,7 @@ class Pitivi(Gtk.Application, Loggable):
     """
 
     __gsignals__ = {
-        "version-info-received": (GObject.SIGNAL_RUN_LAST, None, (object,))
+        "version-info-received": (GObject.SignalFlags.RUN_LAST, None, (object,))
     }
 
     def __init__(self):
diff --git a/pitivi/dialogs/filelisterrordialog.py b/pitivi/dialogs/filelisterrordialog.py
index 0164301d..ab18e77f 100644
--- a/pitivi/dialogs/filelisterrordialog.py
+++ b/pitivi/dialogs/filelisterrordialog.py
@@ -33,8 +33,8 @@ class FileListErrorDialog(GObject.Object, Loggable):
     """Dialog for showing errors blocking importing media files."""
 
     __gsignals__ = {
-        'close': (GObject.SIGNAL_RUN_LAST, None, ()),
-        'response': (GObject.SIGNAL_RUN_LAST, None, (object,))}
+        'close': (GObject.SignalFlags.RUN_LAST, None, ()),
+        'response': (GObject.SignalFlags.RUN_LAST, None, (object,))}
 
     def __init__(self, title, headline):
         GObject.Object.__init__(self)
diff --git a/pitivi/project.py b/pitivi/project.py
index d1158b4b..bb8616fa 100644
--- a/pitivi/project.py
+++ b/pitivi/project.py
@@ -108,16 +108,16 @@ class ProjectManager(GObject.Object, Loggable):
     """
 
     __gsignals__ = {
-        "new-project-loading": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "new-project-created": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "new-project-failed": (GObject.SIGNAL_RUN_LAST, None, (str, str)),
-        "new-project-loaded": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "save-project-failed": (GObject.SIGNAL_RUN_LAST, None, (str, object)),
-        "project-saved": (GObject.SIGNAL_RUN_LAST, None, (object, str)),
-        "closing-project": (GObject.SIGNAL_RUN_LAST, bool, (object,)),
-        "project-closed": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "missing-uri": (GObject.SIGNAL_RUN_LAST, str, (object, str, object)),
-        "reverting-to-saved": (GObject.SIGNAL_RUN_LAST, bool, (object,)),
+        "new-project-loading": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "new-project-created": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "new-project-failed": (GObject.SignalFlags.RUN_LAST, None, (str, str)),
+        "new-project-loaded": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "save-project-failed": (GObject.SignalFlags.RUN_LAST, None, (str, object)),
+        "project-saved": (GObject.SignalFlags.RUN_LAST, None, (object, str)),
+        "closing-project": (GObject.SignalFlags.RUN_LAST, bool, (object,)),
+        "project-closed": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "missing-uri": (GObject.SignalFlags.RUN_LAST, str, (object, str, object)),
+        "reverting-to-saved": (GObject.SignalFlags.RUN_LAST, bool, (object,)),
     }
 
     def __init__(self, app):
diff --git a/pitivi/render.py b/pitivi/render.py
index 14c5a096..28e65b77 100644
--- a/pitivi/render.py
+++ b/pitivi/render.py
@@ -292,8 +292,8 @@ def extension_for_muxer(muxer_name):
 class RenderingProgressDialog(GObject.Object):
 
     __gsignals__ = {
-        "pause": (GObject.SIGNAL_RUN_LAST, None, ()),
-        "cancel": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "pause": (GObject.SignalFlags.RUN_LAST, None, ()),
+        "cancel": (GObject.SignalFlags.RUN_LAST, None, ()),
     }
 
     def __init__(self, app, parent):
diff --git a/pitivi/settings.py b/pitivi/settings.py
index 1376052d..f3a78e2a 100644
--- a/pitivi/settings.py
+++ b/pitivi/settings.py
@@ -348,7 +348,7 @@ class GlobalSettings(GObject.Object, Loggable):
             setattr(cls, "_" + attrname, default)
             GObject.signal_new(notification.signame,
                                cls,
-                               GObject.SIGNAL_RUN_LAST,
+                               GObject.SignalFlags.RUN_LAST,
                                None,
                                ())
         else:
diff --git a/pitivi/shortcuts.py b/pitivi/shortcuts.py
index f91b0bba..f2aeba0f 100644
--- a/pitivi/shortcuts.py
+++ b/pitivi/shortcuts.py
@@ -30,7 +30,7 @@ class ShortcutsManager(GObject.Object):  # pylint: disable=too-many-instance-att
     """Manager storing the shortcuts from all across the app."""
 
     __gsignals__ = {
-        "accel-changed": (GObject.SIGNAL_RUN_LAST, None, (str,))
+        "accel-changed": (GObject.SignalFlags.RUN_LAST, None, (str,))
     }
 
     def __init__(self, app):
diff --git a/pitivi/timeline/elements.py b/pitivi/timeline/elements.py
index e207cd86..618be692 100644
--- a/pitivi/timeline/elements.py
+++ b/pitivi/timeline/elements.py
@@ -87,9 +87,9 @@ class KeyframeCurve(FigureCanvas, Loggable):
 
     __gsignals__ = {
         # Signal the keyframes or the curve are being hovered
-        "enter": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "enter": (GObject.SignalFlags.RUN_LAST, None, ()),
         # Signal the keyframes or the curve are not being hovered anymore
-        "leave": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "leave": (GObject.SignalFlags.RUN_LAST, None, ()),
     }
 
     def __init__(self, timeline, binding):
@@ -595,9 +595,9 @@ class MultipleKeyframeCurve(KeyframeCurve):
 class TimelineElement(Gtk.Layout, Zoomable, Loggable):
     __gsignals__ = {
         # Signal the keyframes curve are being hovered
-        "curve-enter": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "curve-enter": (GObject.SignalFlags.RUN_LAST, None, ()),
         # Signal the keyframes curve are not being hovered anymore
-        "curve-leave": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "curve-leave": (GObject.SignalFlags.RUN_LAST, None, ()),
     }
 
     def __init__(self, element, timeline):
diff --git a/pitivi/timeline/previewers.py b/pitivi/timeline/previewers.py
index 66f4ce32..3dac15b1 100644
--- a/pitivi/timeline/previewers.py
+++ b/pitivi/timeline/previewers.py
@@ -65,8 +65,8 @@ assert Gst.SECOND % THUMB_PERIOD == 0
 WAVEFORM_SURFACE_EXTRA_PX = 500
 
 PREVIEW_GENERATOR_SIGNALS = {
-    "done": (GObject.SIGNAL_RUN_LAST, None, ()),
-    "error": (GObject.SIGNAL_RUN_LAST, None, ()),
+    "done": (GObject.SignalFlags.RUN_LAST, None, ()),
+    "error": (GObject.SignalFlags.RUN_LAST, None, ()),
 }
 
 GlobalSettings.addConfigSection("previewers")
diff --git a/pitivi/undo/undo.py b/pitivi/undo/undo.py
index 692b09d3..3fade910 100644
--- a/pitivi/undo/undo.py
+++ b/pitivi/undo/undo.py
@@ -166,12 +166,12 @@ class UndoableActionLog(GObject.Object, Loggable):
     """
 
     __gsignals__ = {
-        "begin": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "pre-push": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "push": (GObject.SIGNAL_RUN_LAST, None, (object, object)),
-        "rollback": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "commit": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "move": (GObject.SIGNAL_RUN_LAST, None, (object,)),
+        "begin": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "pre-push": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "push": (GObject.SignalFlags.RUN_LAST, None, (object, object)),
+        "rollback": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "commit": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "move": (GObject.SignalFlags.RUN_LAST, None, (object,)),
     }
 
     def __init__(self):
diff --git a/pitivi/utils/proxy.py b/pitivi/utils/proxy.py
index 623ae1a1..d985a4d5 100644
--- a/pitivi/utils/proxy.py
+++ b/pitivi/utils/proxy.py
@@ -79,10 +79,10 @@ class ProxyManager(GObject.Object, Loggable):
     """Transcodes assets and manages proxies."""
 
     __gsignals__ = {
-        "progress": (GObject.SIGNAL_RUN_LAST, None, (object, int, int)),
-        "proxy-ready": (GObject.SIGNAL_RUN_LAST, None, (object, object)),
-        "asset-preparing-cancelled": (GObject.SIGNAL_RUN_LAST, None, (object,)),
-        "error-preparing-asset": (GObject.SIGNAL_RUN_LAST, None, (object,
+        "progress": (GObject.SignalFlags.RUN_LAST, None, (object, int, int)),
+        "proxy-ready": (GObject.SignalFlags.RUN_LAST, None, (object, object)),
+        "asset-preparing-cancelled": (GObject.SignalFlags.RUN_LAST, None, (object,)),
+        "error-preparing-asset": (GObject.SignalFlags.RUN_LAST, None, (object,
                                                                   object,
                                                                   object)),
     }
diff --git a/pitivi/utils/threads.py b/pitivi/utils/threads.py
index 27fad9c1..990689b4 100644
--- a/pitivi/utils/threads.py
+++ b/pitivi/utils/threads.py
@@ -32,7 +32,7 @@ class Thread(threading.Thread, GObject.Object, Loggable):
     """Event-powered thread."""
 
     __gsignals__ = {
-        "done": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "done": (GObject.SignalFlags.RUN_LAST, None, ()),
     }
 
     def __init__(self):
diff --git a/pitivi/utils/timeline.py b/pitivi/utils/timeline.py
index d4d2e905..33669884 100644
--- a/pitivi/utils/timeline.py
+++ b/pitivi/utils/timeline.py
@@ -49,7 +49,7 @@ class Selected(GObject.Object):
     """
 
     __gsignals__ = {
-        "selected-changed": (GObject.SIGNAL_RUN_LAST, None, (bool,)),
+        "selected-changed": (GObject.SignalFlags.RUN_LAST, None, (bool,)),
     }
 
     def __init__(self):
@@ -83,7 +83,7 @@ class Selection(GObject.Object, Loggable):
     """
 
     __gsignals__ = {
-        "selection-changed": (GObject.SIGNAL_RUN_LAST, None, ()),
+        "selection-changed": (GObject.SignalFlags.RUN_LAST, None, ()),
     }
 
     def __init__(self):
diff --git a/tests/test_plugin_manager.py b/tests/test_plugin_manager.py
index 74a6e49a..efede720 100644
--- a/tests/test_plugin_manager.py
+++ b/tests/test_plugin_manager.py
@@ -37,7 +37,7 @@ class TestPluginManager(common.TestCase):
         class App(GObject.Object):
             """A representation of the Pitivi Application for test purposes."""
             __gsignals__ = {
-                "window-added": (GObject.SIGNAL_RUN_LAST, None, (object, ))
+                "window-added": (GObject.SignalFlags.RUN_LAST, None, (object, ))
             }
 
             def __init__(self):


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/pitivi/effects.py b/pitivi/effects.py
index ec5220da..9e8c07f6 100644
--- a/pitivi/effects.py
+++ b/pitivi/effects.py
@@ -623,10 +623,10 @@ class EffectsPropertiesManager(GObject.Object, Loggable):
         return False, handler_return
 
     __gsignals__ = {
-        "create_widget": (GObject.SIGNAL_RUN_LAST, Gtk.Widget, (GstElementSettingsWidget, GES.Effect,),
+        "create_widget": (GObject.SignalFlags.RUN_LAST, Gtk.Widget, (GstElementSettingsWidget, GES.Effect,),
                           create_widget_accumulator),
         "create_property_widget": (
             GObject.SIGNAL_RUN_LAST, object, (GstElementSettingsWidget, GES.Effect, object, object,),
             create_widget_accumulator),
     }
 
@@ -623,10 +623,10 @@ class EffectsPropertiesManager(GObject.Object, Loggable):
                           create_widget_accumulator),
         "create_property_widget": (
-            GObject.SIGNAL_RUN_LAST, object, (GstElementSettingsWidget, GES.Effect, object, object,),
+            GObject.SignalFlags.RUN_LAST, object, (GstElementSettingsWidget, GES.Effect, object, object,),
             create_widget_accumulator),
     }